==> 0.2.0.tar.gz: lib/ColorSelector/ColorTabView.dart <==
import 'package:flutter/material.dart';

import 'ColorContainer.dart';
import 'ColorDescriptor.dart';
import 'ColorPalette.dart';

class ColorTabView extends StatefulWidget {
  const ColorTabView({
    Key? key,
    required this.colorPalette,
    this.onDoubleTap,
    this.onTap,
  }) : super(key: key);

  final ColorPalette colorPalette;
  final ValueSetter<ColorDescriptor>? onTap;
  final ValueSetter<ColorDescriptor>? onDoubleTap;

  @override
  _ColorTabViewState createState() => _ColorTabViewState();
}

class _ColorTabViewState extends State<ColorTabView> {
  ColorDescriptor? selectedColor;
  late List<ColorDescriptor> colorDescriptors;

  @override
  void initState() {
    colorDescriptors = widget.colorPalette.getVariants(withBaseColor: !widget.colorPalette.singleColor);
    // selectedColor = colorDescriptors.first;

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final textTheme = Theme.of(context).textTheme;
    final whiteTextStyle = textTheme.bodyText2!.copyWith(
      color: Colors.white,
    );
    final blackTextStyle = textTheme.bodyText2!.copyWith(
      color: Colors.black,
    );

    final items = ListView.builder(
      itemCount: colorDescriptors.length,
      itemBuilder: (context, index) {
        final item = colorDescriptors[index];

        return DefaultTextStyle(
          style: item.contrastColor == Colors.white ? whiteTextStyle : blackTextStyle,
          child: ColorContainer(
            colorDescriptor: item,
            isSelected: selectedColor == item,
            onTap: (value) {
              setState(() {
                selectedColor = value;
              });
              if (widget.onTap != null) {
                widget.onTap!(value);
              }
            },
            onDoubleTap: widget.onDoubleTap,
          ),
        );
      },
    );

    return Scrollbar(
      child: items,
    );
  }
}

==> 0.2.2.tar.gz: lib/ColorSelector/ColorTabView.dart <==
import 'package:flutter/material.dart';

import 'ColorContainer.dart';
import 'ColorDescriptor.dart';
import 'ColorPalette.dart';

class ColorTabView extends StatefulWidget {
  const ColorTabView({
    Key? key,
    required this.colorPalette,
    this.onDoubleTap,
    this.onTap,
  }) : super(key: key);

  final ColorPalette colorPalette;
  final ValueSetter<ColorDescriptor>? onTap;
  final ValueSetter<ColorDescriptor>? onDoubleTap;

  @override
  _ColorTabViewState createState() => _ColorTabViewState();
}

class _ColorTabViewState extends State<ColorTabView> {
  ColorDescriptor? selectedColor;
  late List<ColorDescriptor> colorDescriptors;

  @override
  void initState() {
    colorDescriptors = widget.colorPalette.getVariants();
    // selectedColor = colorDescriptors.first;

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final textTheme = Theme.of(context).textTheme;
    final whiteTextStyle = textTheme.bodyText2!.copyWith(
      color: Colors.white,
    );
    final blackTextStyle = textTheme.bodyText2!.copyWith(
      color: Colors.black,
    );

    final items = ListView.builder(
      itemCount: colorDescriptors.length,
      itemBuilder: (context, index) {
        final item = colorDescriptors[index];

        return DefaultTextStyle(
          style: item.contrastColor == Colors.white ? whiteTextStyle : blackTextStyle,
          child: ColorContainer(
            colorDescriptor: item,
            isSelected: selectedColor == item,
            onTap: (value) {
              setState(() {
                selectedColor = value;
              });
              if (widget.onTap != null) {
                widget.onTap!(value);
              }
            },
            onDoubleTap: widget.onDoubleTap,
          ),
        );
      },
    );

    return Scrollbar(
      child: items,
    );
  }
}
